import React from 'react'
import EditRegistermap from './EditRegistermap'
import EditSetting from './EditSetting'
import './registermap.css'

class ShowRegistermap extends React.Component {
  constructor () {
    super()
    this.sayMyName = this.sayMyName.bind(this)
    this.table = this.table.bind(this)

    this.bitmap = {}
  }

  sayMyName (event) {
    event.preventDefault()
    console.log('Hi, my name is', event)
  }

  table (registermap, settings) {
    // Generate a table with rows for registers and columns for bits
    let trow = []
    let idx

    const thead = []
    const tbody = []

    for (let idxCol = 0; idxCol < registermap.bitsPerRegister; idxCol += 1) {
      trow.push(<th key={idxCol}>{idxCol}</th>)
    }
    trow.push(<th key={registermap.bitsPerRegister}>Register Name</th>)
    thead.push(<tr key={-1}>{trow}</tr>)

    for (let idxRow = 0; idxRow < registermap.nrOfRegisters; idxRow += 1) {
      trow = []
      for (let idxCol = 0; idxCol < registermap.bitsPerRegister; idxCol += 1) {
        idx = idxRow * registermap.bitsPerRegister + idxCol
        this.bitmap[idx] = ''
        trow.push(<td key={idx} onClick={this.sayMyName}>{this.bitmap[idx]}</td>)
      }
      trow.push(<td key={`inp${idxRow}`}><input ref={input => { this.bitmap[idxRow] = input }} type='text' placeholder={`register${idxRow}`} onChange={this.updateRegister} /></td>)
      tbody.push(<tr key={idxRow}>{trow}</tr>)
    }
    return (
      <table>
        <thead>{thead}</thead>
        <tbody>{tbody}</tbody>
      </table>
    )
  }

  render () {
    const { registermap, settingList, actions } = this.props
    console.log('Show registermap', registermap, settingList, actions)
    if (typeof settingList === 'undefined') {
      return (
        <p>Please select a registermap</p>
      )
    }

    return (
      <div className='content-flex'>
        <div className='content-main'>
          <h2>Registermap {registermap.name}</h2>
          <EditRegistermap registermap={registermap} actions={actions} />
          <h2>Registers</h2>
          {this.table(registermap, settingList)}
          <div>Warning: Not all settings fit in the registers!</div>
        </div>
        <div className='content-aside-right'>
          <h2>Settings</h2>
          {settingList.map((value, idx) => {
            return (
              <EditSetting key={idx} setting={value} actions={actions} />
            )
          }
          )}
        </div>
      </div>
    )
  }
}

export default ShowRegistermap
